# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class XML(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'namespace': 'str',
        'prefix': 'str',
        'attribute': 'bool',
        'wrapped': 'bool',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'name': 'name',
        'namespace': 'namespace',
        'prefix': 'prefix',
        'attribute': 'attribute',
        'wrapped': 'wrapped',
        'extensions': 'extensions'
    }

    def __init__(self, name=None, namespace=None, prefix=None, attribute=None, wrapped=None, extensions=None):  # noqa: E501
        """XML - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._namespace = None
        self._prefix = None
        self._attribute = None
        self._wrapped = None
        self._extensions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if namespace is not None:
            self.namespace = namespace
        if prefix is not None:
            self.prefix = prefix
        if attribute is not None:
            self.attribute = attribute
        if wrapped is not None:
            self.wrapped = wrapped
        if extensions is not None:
            self.extensions = extensions

    @property
    def name(self):
        """Gets the name of this XML.  # noqa: E501


        :return: The name of this XML.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this XML.


        :param name: The name of this XML.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this XML.  # noqa: E501


        :return: The namespace of this XML.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this XML.


        :param namespace: The namespace of this XML.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def prefix(self):
        """Gets the prefix of this XML.  # noqa: E501


        :return: The prefix of this XML.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this XML.


        :param prefix: The prefix of this XML.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    @property
    def attribute(self):
        """Gets the attribute of this XML.  # noqa: E501


        :return: The attribute of this XML.  # noqa: E501
        :rtype: bool
        """
        return self._attribute

    @attribute.setter
    def attribute(self, attribute):
        """Sets the attribute of this XML.


        :param attribute: The attribute of this XML.  # noqa: E501
        :type: bool
        """

        self._attribute = attribute

    @property
    def wrapped(self):
        """Gets the wrapped of this XML.  # noqa: E501


        :return: The wrapped of this XML.  # noqa: E501
        :rtype: bool
        """
        return self._wrapped

    @wrapped.setter
    def wrapped(self, wrapped):
        """Sets the wrapped of this XML.


        :param wrapped: The wrapped of this XML.  # noqa: E501
        :type: bool
        """

        self._wrapped = wrapped

    @property
    def extensions(self):
        """Gets the extensions of this XML.  # noqa: E501


        :return: The extensions of this XML.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this XML.


        :param extensions: The extensions of this XML.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XML):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTGlobalTreeNodeOwnerParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resource_type': 'str',
        'new_owner_type': 'int',
        'new_owner_id': 'str',
        'resource_id': 'str'
    }

    attribute_map = {
        'resource_type': 'resourceType',
        'new_owner_type': 'newOwnerType',
        'new_owner_id': 'newOwnerId',
        'resource_id': 'resourceId'
    }

    def __init__(self, resource_type=None, new_owner_type=None, new_owner_id=None, resource_id=None):  # noqa: E501
        """BTGlobalTreeNodeOwnerParams - a model defined in OpenAPI"""  # noqa: E501

        self._resource_type = None
        self._new_owner_type = None
        self._new_owner_id = None
        self._resource_id = None
        self.discriminator = None

        if resource_type is not None:
            self.resource_type = resource_type
        if new_owner_type is not None:
            self.new_owner_type = new_owner_type
        if new_owner_id is not None:
            self.new_owner_id = new_owner_id
        if resource_id is not None:
            self.resource_id = resource_id

    @property
    def resource_type(self):
        """Gets the resource_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501


        :return: The resource_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this BTGlobalTreeNodeOwnerParams.


        :param resource_type: The resource_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def new_owner_type(self):
        """Gets the new_owner_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501


        :return: The new_owner_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :rtype: int
        """
        return self._new_owner_type

    @new_owner_type.setter
    def new_owner_type(self, new_owner_type):
        """Sets the new_owner_type of this BTGlobalTreeNodeOwnerParams.


        :param new_owner_type: The new_owner_type of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :type: int
        """

        self._new_owner_type = new_owner_type

    @property
    def new_owner_id(self):
        """Gets the new_owner_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501


        :return: The new_owner_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :rtype: str
        """
        return self._new_owner_id

    @new_owner_id.setter
    def new_owner_id(self, new_owner_id):
        """Sets the new_owner_id of this BTGlobalTreeNodeOwnerParams.


        :param new_owner_id: The new_owner_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :type: str
        """

        self._new_owner_id = new_owner_id

    @property
    def resource_id(self):
        """Gets the resource_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501


        :return: The resource_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this BTGlobalTreeNodeOwnerParams.


        :param resource_id: The resource_id of this BTGlobalTreeNodeOwnerParams.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTGlobalTreeNodeOwnerParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBelScriptLibraryVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'major': 'int',
        'minor': 'int',
        'valid': 'bool',
        'version_number': 'int',
        'point': 'int'
    }

    attribute_map = {
        'major': 'major',
        'minor': 'minor',
        'valid': 'valid',
        'version_number': 'versionNumber',
        'point': 'point'
    }

    def __init__(self, major=None, minor=None, valid=None, version_number=None, point=None):  # noqa: E501
        """BTBelScriptLibraryVersion - a model defined in OpenAPI"""  # noqa: E501

        self._major = None
        self._minor = None
        self._valid = None
        self._version_number = None
        self._point = None
        self.discriminator = None

        if major is not None:
            self.major = major
        if minor is not None:
            self.minor = minor
        if valid is not None:
            self.valid = valid
        if version_number is not None:
            self.version_number = version_number
        if point is not None:
            self.point = point

    @property
    def major(self):
        """Gets the major of this BTBelScriptLibraryVersion.  # noqa: E501


        :return: The major of this BTBelScriptLibraryVersion.  # noqa: E501
        :rtype: int
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this BTBelScriptLibraryVersion.


        :param major: The major of this BTBelScriptLibraryVersion.  # noqa: E501
        :type: int
        """

        self._major = major

    @property
    def minor(self):
        """Gets the minor of this BTBelScriptLibraryVersion.  # noqa: E501


        :return: The minor of this BTBelScriptLibraryVersion.  # noqa: E501
        :rtype: int
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this BTBelScriptLibraryVersion.


        :param minor: The minor of this BTBelScriptLibraryVersion.  # noqa: E501
        :type: int
        """

        self._minor = minor

    @property
    def valid(self):
        """Gets the valid of this BTBelScriptLibraryVersion.  # noqa: E501


        :return: The valid of this BTBelScriptLibraryVersion.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this BTBelScriptLibraryVersion.


        :param valid: The valid of this BTBelScriptLibraryVersion.  # noqa: E501
        :type: bool
        """

        self._valid = valid

    @property
    def version_number(self):
        """Gets the version_number of this BTBelScriptLibraryVersion.  # noqa: E501


        :return: The version_number of this BTBelScriptLibraryVersion.  # noqa: E501
        :rtype: int
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this BTBelScriptLibraryVersion.


        :param version_number: The version_number of this BTBelScriptLibraryVersion.  # noqa: E501
        :type: int
        """

        self._version_number = version_number

    @property
    def point(self):
        """Gets the point of this BTBelScriptLibraryVersion.  # noqa: E501


        :return: The point of this BTBelScriptLibraryVersion.  # noqa: E501
        :rtype: int
        """
        return self._point

    @point.setter
    def point(self, point):
        """Sets the point of this BTBelScriptLibraryVersion.


        :param point: The point of this BTBelScriptLibraryVersion.  # noqa: E501
        :type: int
        """

        self._point = point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBelScriptLibraryVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""For testing all the example programs in the example program directory."""
import os
from pathlib import Path

example_programs=[]
example_programs.append('example_programs/export_step')

def test_example_programs(script_runner):
    example_programs_dir = Path(os.getcwd()) / "example_programs"

    for script in example_programs_dir.iterdir():
        ret = script_runner.run(str(script))
        assert ret.success


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCustomPropertyDefinitionParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'description': 'str',
        'enum_definition': 'list[str]',
        'template': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'enum_definition': 'enumDefinition',
        'template': 'template'
    }

    def __init__(self, name=None, type=None, description=None, enum_definition=None, template=None):  # noqa: E501
        """BTCustomPropertyDefinitionParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._type = None
        self._description = None
        self._enum_definition = None
        self._template = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if enum_definition is not None:
            self.enum_definition = enum_definition
        if template is not None:
            self.template = template

    @property
    def name(self):
        """Gets the name of this BTCustomPropertyDefinitionParams.  # noqa: E501


        :return: The name of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTCustomPropertyDefinitionParams.


        :param name: The name of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this BTCustomPropertyDefinitionParams.  # noqa: E501


        :return: The type of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTCustomPropertyDefinitionParams.


        :param type: The type of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRING", "NUMBER", "INTEGER", "BOOLEAN", "DATE", "ENUM", "BLOB", "OBJECT", "ARRAY", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def description(self):
        """Gets the description of this BTCustomPropertyDefinitionParams.  # noqa: E501


        :return: The description of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTCustomPropertyDefinitionParams.


        :param description: The description of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enum_definition(self):
        """Gets the enum_definition of this BTCustomPropertyDefinitionParams.  # noqa: E501


        :return: The enum_definition of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._enum_definition

    @enum_definition.setter
    def enum_definition(self, enum_definition):
        """Sets the enum_definition of this BTCustomPropertyDefinitionParams.


        :param enum_definition: The enum_definition of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :type: list[str]
        """

        self._enum_definition = enum_definition

    @property
    def template(self):
        """Gets the template of this BTCustomPropertyDefinitionParams.  # noqa: E501


        :return: The template of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this BTCustomPropertyDefinitionParams.


        :param template: The template of this BTCustomPropertyDefinitionParams.  # noqa: E501
        :type: str
        """

        self._template = template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCustomPropertyDefinitionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from onshape_client.configuration import Configuration
import onshape_client
from pathlib import Path
from ruamel.yaml import YAML
import os


class Client:
    """
    Initialize an Onshape client.

    The default is to pull the configuration from a file located in the user's home
    directory. However, configs can also be passed directly as a dictionary.

    Keys can be obtained from https://dev-portal.onshape.com.

    Parameters
    ----------
    conf_file : :obj:`str`, optional
        The path to the location of an onshape_client_config YAML file, where multiple stacks may be declared.
    configuration : :obj:`dict`, optional
        This overrides the conf_file parameter by supplying a dictionary that looks like the following:
        {
            "base_url": "https://cad.onshape.com",
            "access_key": "YOUR_ACCESS_KEY_HERE",
            "secret_key": "YOUR_SECRET_KEY_HERE"
        }
    stack_key : :obj:`str`, optional
        The key of the name for the particular stack to be used. Only applicable when reading configuration from the
        conf_file.
    """
    def __init__(self, keys_file="~/.onshape_client_config.yaml", configuration=None, stack_key=None):
        keys_file = os.path.expanduser(keys_file)
        if configuration:
            final_configuration = configuration
        elif keys_file:
            try:
                yaml = YAML()
                configurations_file = yaml.load(Path(keys_file))
                final_configuration = configurations_file[stack_key if stack_key else configurations_file['default_stack']]
            except KeyError as e:
                raise KeyError("Your creds file is not constructed as expected: {}".format(e))
        else:
            raise EnvironmentError("API keys were not properly set.")

        self._set_configuration(final_configuration)
        self._create_apis()

    def _set_configuration(self, configuration_dictionary):
        configuration = Configuration()
        configuration.api_key['SECRET_KEY'] = configuration_dictionary['secret_key']
        configuration.api_key['ACCESS_KEY'] = configuration_dictionary['access_key']
        configuration.host = configuration_dictionary['base_url']
        self.configuration = configuration

    def _create_apis(self):
        api_client = onshape_client.ApiClient(configuration=self.configuration)

        self.accounts_api = onshape_client.api.AccountsApi(api_client)
        self.app_elements_api = onshape_client.api.AppElementsApi(api_client)
        self.assemblies_api = onshape_client.api.AssembliesApi(api_client)
        self.blob_elements_api = onshape_client.api.BlobElementsApi(api_client)
        self.documents_api = onshape_client.api.DocumentsApi(api_client)
        self.elements_api = onshape_client.api.ElementsApi(api_client)
        self.endpoints_api = onshape_client.api.EndpointsApi(api_client)
        self.metadata_api = onshape_client.api.MetadataApi(api_client)
        self.parts_api = onshape_client.api.PartsApi(api_client)
        self.part_studios_api = onshape_client.api.PartStudiosApi(api_client)
        self.translation_api = onshape_client.api.TranslationsApi(api_client)
